﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.DataFormats;

namespace AirplaneWithRadar
{
    public partial class FormMapWithSetAirplane : Form
    {
        /// <summary>
        /// Объект от класса карты с набором объектов
        /// </summary>
        private MapWithSetAirplaneGeneric<DrawningObjectAirplane, AbstractMap> _mapAirplaneCollectionGeneric;
        public FormMapWithSetAirplane()
        {
            InitializeComponent();
        }
        /// <summary>
        /// Выбор карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ComboBoxSelectorMap_SelectedIndexChanged(object sender, EventArgs e)
        {
            AbstractMap map = null;
            switch (comboBoxSelectorMap.Text)
            {
                case "Простая карта":
                    map = new SimpleMap();
                    break;
                case "Карта неба с облаками":
                    map = new SkyMap();
                    break;
                case "Карта туманного неба с грозой":
                    map = new FoggySkyMap();
                    break;
            }
            if (map != null)
            {
                _mapAirplaneCollectionGeneric = new MapWithSetAirplaneGeneric<DrawningObjectAirplane, AbstractMap>(
                    pictureBox.Width, pictureBox.Height, map);
            }
            else
            {
                _mapAirplaneCollectionGeneric = null;
            }
        }
        /// <summary>
        /// Добавление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonAddAirplane_Click(object sender, EventArgs e)
        {
            if (_mapAirplaneCollectionGeneric == null)
            {
                return;
            }
            FormAirplane form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                DrawningObjectAirplane airplane = new(form.SelectedAirplane);
                if (_mapAirplaneCollectionGeneric + airplane != -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBox.Image = _mapAirplaneCollectionGeneric.ShowSet();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }
        /// <summary>
        /// Удаление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRemoveAirplane_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(maskedTextBoxPosition.Text))
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
            if (_mapAirplaneCollectionGeneric - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBox.Image = _mapAirplaneCollectionGeneric.ShowSet();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }
        /// <summary>
        /// Вывод набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowStorage_Click(object sender, EventArgs e)
        {
            if (_mapAirplaneCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapAirplaneCollectionGeneric.ShowSet();
        }
        /// <summary>
        /// Вывод карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowOnMap_Click(object sender, EventArgs e)
        {
            if (_mapAirplaneCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapAirplaneCollectionGeneric.ShowOnMap();
        }
        /// <summary>
        /// Перемещение
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonMove_Click(object sender, EventArgs e)
        {
            if (_mapAirplaneCollectionGeneric == null)
            {
                return;
            }
            //получаем имя кнопки
            string name = ((Button)sender)?.Name ?? string.Empty;
            Direction dir = Direction.None;
            switch (name)
            {
                case "buttonUp":
                    dir = Direction.Up;
                    break;
                case "buttonDown":
                    dir = Direction.Down;
                    break;
                case "buttonLeft":
                    dir = Direction.Left;
                    break;
                case "buttonRight":
                    dir = Direction.Right;
                    break;
            }
            pictureBox.Image = _mapAirplaneCollectionGeneric.MoveObject(dir);
        }
    }
}
